package com.example.workflow;

import jakarta.inject.Named;
import javax.inject.Inject;
import org.camunda.bpm.engine.delegate.DelegateExecution;
import org.camunda.bpm.engine.delegate.JavaDelegate;
import org.springframework.beans.factory.annotation.Autowired;

import javax.mail.*;
import javax.mail.internet.*;
import java.util.Properties;

@Named
public class RequestMoreInfoNotificationService implements JavaDelegate {

    @Autowired
    private EmailConfig emailConfig;
    
    @Override
    public void execute(DelegateExecution execution) throws Exception {
        // 1. Retrieve username (assuming it holds the recipient email)
        String recipientEmail = (String) execution.getVariable("EmailAddress");

        // 2. Construct notification message
        String updateMessage = "We require additional information to proceed with your ticket. \nPlease provide the necessary details from the webportal.";

        // 3. Send notification email
        sendNotificationEmail(recipientEmail, updateMessage, "Additional Information Required!");
    }

    private void sendNotificationEmail(String recipientEmail, String messageBody, String subject) {
        // Email configuration
        String host = "smtp.gmail.com";
        String username = emailConfig.getEmailAddress();
        String password = emailConfig.getEmailPassword();

        Properties props = new Properties();
        props.put("mail.smtp.auth", "true");
        props.put("mail.smtp.starttls.enable", "true");
        props.put("mail.smtp.host", host);
        props.put("mail.smtp.port", "587");

        // Create session with authentication
        Session session = Session.getInstance(props, new Authenticator() {
            @Override
            protected PasswordAuthentication getPasswordAuthentication() {
                return new PasswordAuthentication(username, password);
            }
        });

        try {
            // Create MimeMessage object
            Message message = new MimeMessage(session);

            // Set From: header field
            message.setFrom(new InternetAddress(username));

            // Set To: header field
            message.setRecipients(Message.RecipientType.TO, InternetAddress.parse(recipientEmail));

            // Set Subject: header field
            message.setSubject(subject);

            // Set message body
            message.setText(messageBody);

            // Send email
            Transport.send(message);

            System.out.println("Email sent successfully to " + recipientEmail);
        } catch (MessagingException e) {
            throw new RuntimeException(e);
        }
    }
}