import com.example.workflow.AutoFill;
import org.camunda.bpm.engine.delegate.DelegateExecution;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.MockitoAnnotations;
import org.springframework.jdbc.core.JdbcTemplate;

import static org.junit.jupiter.api.Assertions.*;
import static org.mockito.Mockito.*;

public class AutoFillTest {

    @Mock
    private JdbcTemplate jdbcTemplate;

    @Mock
    private DelegateExecution execution;

    @InjectMocks
    private AutoFill autoFill;

    @BeforeEach
    public void setUp() {
        MockitoAnnotations.initMocks(this);
    }

    @Test
    public void testExecute_UserExists() {
        // Arrange
        String email = "test@example.com";
        String username = "test_user";
        when(execution.getVariable("checkUser")).thenReturn(true);
        when(execution.getVariable("EmailAddress")).thenReturn(email);
        when(jdbcTemplate.queryForObject(anyString(), any(Object[].class), eq(String.class))).thenReturn(username);

        // Act
        assertDoesNotThrow(() -> autoFill.execute(execution));

        // Assert
        verify(execution).setVariable("userName", username);
        System.out.println("user does exist");
    }

    @Test
    public void testExecute_UserDoesNotExist() {
        // Arrange
        String email = "nonexistent@example.com";
        when(execution.getVariable("checkUser")).thenReturn(true);
        when(execution.getVariable("EmailAddress")).thenReturn(email);
        doReturn(null).when(jdbcTemplate).queryForObject(anyString(), any(Object[].class), eq(String.class));

        // Act
        assertDoesNotThrow(() -> autoFill.execute(execution));

        // Assert
        verify(execution, times(0)).setVariable(eq("random user"), any());
        System.out.println("user does not exist");
    }

    @Test
    public void testExecute_UserDoesNotExist_VariableNotSet() {
        // Arrange
        String email = "nonexistent@example.com";
        when(execution.getVariable("checkUser")).thenReturn(false);
        when(execution.getVariable("EmailAddress")).thenReturn(email);

        // Act
        assertDoesNotThrow(() -> autoFill.execute(execution));

        // Assert
        verify(execution, never()).setVariable(eq("userName"), any());
        System.out.println("user does not exist");
    }
}
