import org.camunda.bpm.engine.delegate.DelegateExecution;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.MockitoAnnotations;
import org.springframework.jdbc.core.JdbcTemplate;
import com.example.workflow.CheckUser;
import org.springframework.jdbc.core.RowMapper;

import java.util.Collections;

import static org.junit.jupiter.api.Assertions.*;
import static org.mockito.Mockito.*;

public class CheckUserTest {

    @Mock
    private JdbcTemplate jdbcTemplate;

    @Mock
    private DelegateExecution execution;

    @InjectMocks
    private CheckUser checkUser;

    @BeforeEach
    public void setUp() {
        MockitoAnnotations.initMocks(this);
    }

    @Test
    public void testExecute_UserExists() {
        // Arrange
        String email = "existing@example.com";
        String password = "password123";
        when(execution.getVariable("EmailAddress")).thenReturn(email);
        when(execution.getVariable("password")).thenReturn(password);
        when(jdbcTemplate.query(anyString(), any(Object[].class), any(RowMapper.class))).thenReturn(Collections.singletonList(1));

        // Act
        assertDoesNotThrow(() -> checkUser.execute(execution));

        // Assert
        verify(execution).setVariable("checkUser", true);
        System.out.println("user does exist");
    }

    @Test
    public void testExecute_UserDoesNotExist() {
        // Arrange
        String email = "nonexistent@example.com";
        String password = "password456";
        when(execution.getVariable("EmailAddress")).thenReturn(email);
        when(execution.getVariable("password")).thenReturn(password);
        when(jdbcTemplate.query(anyString(), any(Object[].class), any(RowMapper.class))).thenReturn(Collections.emptyList());

        // Act
        assertDoesNotThrow(() -> checkUser.execute(execution));

        // Assert
        verify(execution).setVariable("checkUser", false);
        System.out.println("user does not exist");
    }
}