import org.camunda.bpm.engine.delegate.DelegateExecution;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.MockitoAnnotations;
import static org.mockito.Mockito.*;
import com.example.workflow.CombineIssueInfo;
import org.mockito.junit.jupiter.MockitoExtension;

@ExtendWith(MockitoExtension.class)
public class CombineIssueInfoTest {

    @Mock
    private DelegateExecution delegateExecution;

    @InjectMocks
    private CombineIssueInfo combineIssueInfo;

    @Test
    public void testExecute_BothFieldsNonNull() throws Exception {
        // Arrange
        String issueDescription = "Description";
        String additionalInfo = "Additional Information";

        when(delegateExecution.getVariable("issueDescription")).thenReturn(issueDescription);
        when(delegateExecution.getVariable("additionalInfo")).thenReturn(additionalInfo);

        // Act
        combineIssueInfo.execute(delegateExecution);

        // Assert
        verify(delegateExecution).setVariable("issueDescription", issueDescription + " [ADDITIONAL INFO] " + additionalInfo);
    }

    @Test
    public void testExecute_AdditionalInfoNull() throws Exception {
        // Arrange
        String issueDescription = "Description";
        String additionalInfo = null;

        when(delegateExecution.getVariable("issueDescription")).thenReturn(issueDescription);
        when(delegateExecution.getVariable("additionalInfo")).thenReturn(additionalInfo);

        // Act
        combineIssueInfo.execute(delegateExecution);

        // Assert
        verify(delegateExecution).setVariable("issueDescription", issueDescription + " [ADDITIONAL INFO] Unknown");
    }

    @Test
    public void testExecute_IssueDescriptionNull() throws Exception {
        // Arrange
        String issueDescription = null;
        String additionalInfo = "Additional Information";

        when(delegateExecution.getVariable("issueDescription")).thenReturn(issueDescription);
        when(delegateExecution.getVariable("additionalInfo")).thenReturn(additionalInfo);

        // Act
        combineIssueInfo.execute(delegateExecution);

        // Assert
        verify(delegateExecution).setVariable("issueDescription", "Unknown [ADDITIONAL INFO] " + additionalInfo);
    }

    @Test
    public void testExecute_BothFieldsNull() throws Exception {
        // Arrange
        String issueDescription = null;
        String additionalInfo = null;

        when(delegateExecution.getVariable("issueDescription")).thenReturn(issueDescription);
        when(delegateExecution.getVariable("additionalInfo")).thenReturn(additionalInfo);

        // Act
        combineIssueInfo.execute(delegateExecution);

        // Assert
        verify(delegateExecution).setVariable("issueDescription", "Unknown [ADDITIONAL INFO] Unknown");
    }
}