import org.camunda.bpm.engine.delegate.DelegateExecution;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.mockito.Mock;
import org.mockito.MockitoAnnotations;
import static org.junit.jupiter.api.Assertions.assertEquals;
import com.example.workflow.EstimatedTotalTime;
import static org.mockito.Mockito.*;
import org.camunda.bpm.engine.delegate.BpmnError;

public class EstimatedTotalTimeTest {

    @Mock
    private DelegateExecution delegateExecution;

    @BeforeEach
    public void initMocks() {
        MockitoAnnotations.initMocks(this);
    }

    @Test
    public void testLowEffectLowPriority() throws Exception {
        // Set delegate execution variables with "Low" effect and "Low" priority
        when(delegateExecution.getVariable("effect")).thenReturn("Low");
        when(delegateExecution.getVariable("priority")).thenReturn("Low");

        // Create an instance of EstimatedTotalTime
        EstimatedTotalTime estimatedTotalTime = new EstimatedTotalTime();

        // Call the method under test
        estimatedTotalTime.execute(delegateExecution);

        // Verify that the estimated time is set to "8 days"
        verify(delegateExecution).setVariable("estimatedTime", "8 days");
    }

    @Test
    public void testMediumEffectMediumPriority() throws Exception {
        // Set delegate execution variables with "Medium" effect and "Medium" priority
        when(delegateExecution.getVariable("effect")).thenReturn("Medium");
        when(delegateExecution.getVariable("priority")).thenReturn("Medium");

        // Create an instance and call the method
        EstimatedTotalTime estimatedTotalTime = new EstimatedTotalTime();
        estimatedTotalTime.execute(delegateExecution);

        // Verify that the estimated time is set to "5 days"
        verify(delegateExecution).setVariable("estimatedTime", "5 days");
    }

    @Test
    public void testHighEffectHighPriority() throws Exception {
        // Set delegate execution variables with "High" effect and "High" priority
        when(delegateExecution.getVariable("effect")).thenReturn("High");
        when(delegateExecution.getVariable("priority")).thenReturn("High");

        // Create an instance and call the method
        EstimatedTotalTime estimatedTotalTime = new EstimatedTotalTime();
        estimatedTotalTime.execute(delegateExecution);

        // Verify that the estimated time is set to "2 days"
        verify(delegateExecution).setVariable("estimatedTime", "2 days");
    }

    @Test
    public void testInvalidEffect() throws Exception {
        // Set delegate execution variables with invalid effect ("Invalid")
        when(delegateExecution.getVariable("effect")).thenReturn("Invalid");
        when(delegateExecution.getVariable("priority")).thenReturn("Low");

        // Create an instance and call the method
        EstimatedTotalTime estimatedTotalTime = new EstimatedTotalTime();
        estimatedTotalTime.execute(delegateExecution);
    }

    @Test
    public void testInvalidPriority() throws Exception {
        // Set delegate execution variables with valid effect and invalid priority ("Invalid")
        when(delegateExecution.getVariable("effect")).thenReturn("Low");
        when(delegateExecution.getVariable("priority")).thenReturn("Invalid");

        // Create an instance and call the method
        EstimatedTotalTime estimatedTotalTime = new EstimatedTotalTime();
        estimatedTotalTime.execute(delegateExecution);
    }
}