import com.example.workflow.InsertTicketDataDelegate;
import org.camunda.bpm.engine.delegate.DelegateExecution;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.MockitoAnnotations;
import org.springframework.jdbc.core.JdbcTemplate;
import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.mockito.Mockito.*;

public class InsertTicketDataDelegateTest {

    @Mock
    private JdbcTemplate jdbcTemplate;

    @Mock
    private DelegateExecution delegateExecution;

    @InjectMocks
    private InsertTicketDataDelegate insertTicketDataDelegate;

    @BeforeEach
    void setUp() {
        MockitoAnnotations.initMocks(this);
    }

    @Test
    public void testExecute_Successful() throws Exception {
        // Arrange
        String username = "testUser";
        String email = "test@example.com";
        String issueTopic = "Test issue";
        String issueDescription = "Test description";
        String effect = "Test effect";
        String priority = "High";
        String estimatedTime = "1 day";

        when(delegateExecution.getVariable("userName")).thenReturn(username);
        when(delegateExecution.getVariable("EmailAddress")).thenReturn(email);
        when(delegateExecution.getVariable("issueTopic")).thenReturn(issueTopic);
        when(delegateExecution.getVariable("issueDescription")).thenReturn(issueDescription);
        when(delegateExecution.getVariable("effect")).thenReturn(effect);
        when(delegateExecution.getVariable("priority")).thenReturn(priority);
        when(delegateExecution.getVariable("estimatedTime")).thenReturn(estimatedTime);

        when(jdbcTemplate.update(anyString(), any(), any(), any(), any(), any(), any(), any(), any())).thenReturn(1);

        // Act
        insertTicketDataDelegate.execute(delegateExecution);

        // Assert
        verify(jdbcTemplate).update(anyString(), eq(username), eq(email), eq(issueTopic), eq(issueDescription), eq(effect), eq(priority), eq(estimatedTime), eq("Open"));
        verify(delegateExecution).setVariable("ticketSaved", true);
    }

    @Test
    public void testExecute_Unsuccessful() throws Exception {
        // Arrange
        String username = "testUser";
        String email = "test@example.com";
        String issueTopic = "Test issue";
        String issueDescription = "Test description";
        String effect = "Test effect";
        String priority = "High";
        String estimatedTime = "1 day";

        when(delegateExecution.getVariable("userName")).thenReturn(username);
        when(delegateExecution.getVariable("EmailAddress")).thenReturn(email);
        when(delegateExecution.getVariable("issueTopic")).thenReturn(issueTopic);
        when(delegateExecution.getVariable("issueDescription")).thenReturn(issueDescription);
        when(delegateExecution.getVariable("effect")).thenReturn(effect);
        when(delegateExecution.getVariable("priority")).thenReturn(priority);
        when(delegateExecution.getVariable("estimatedTime")).thenReturn(estimatedTime);

        when(jdbcTemplate.update(anyString(), any(), any(), any(), any(), any(), any(), any(), any())).thenReturn(0);

        // Act
        insertTicketDataDelegate.execute(delegateExecution);

        // Assert
        verify(jdbcTemplate).update(anyString(), eq(username), eq(email), eq(issueTopic), eq(issueDescription), eq(effect), eq(priority), eq(estimatedTime), eq("Open"));
        verify(delegateExecution).setVariable("ticketSaved", false);
    }
}