import org.camunda.bpm.engine.delegate.DelegateExecution;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.MockitoAnnotations;
import org.springframework.jdbc.core.JdbcTemplate;
import com.example.workflow.SurveyDataDelegate;
import static org.junit.jupiter.api.Assertions.assertDoesNotThrow;
import static org.mockito.Mockito.*;

class SurveyDataDelegateTest {

    @Mock
    private JdbcTemplate jdbcTemplate;

    @Mock
    private DelegateExecution delegateExecution;

    @InjectMocks
    private SurveyDataDelegate surveyDataDelegate;

    @BeforeEach
    void setUp() {
        MockitoAnnotations.initMocks(this);
    }

    @Test
    void testExecute() {
        // Arrange
        String staffSolutionSatisfaction = "Satisfied";
        String timingSatisfaction = "On time";
        String improvementIdea = "Improve communication";

        when(delegateExecution.getVariable("staff_Opinion")).thenReturn(staffSolutionSatisfaction);
        when(delegateExecution.getVariable("Timing")).thenReturn(timingSatisfaction);
        when(delegateExecution.getVariable("ideaSolution")).thenReturn(improvementIdea);

        // Act
        assertDoesNotThrow(() -> surveyDataDelegate.execute(delegateExecution));

        // Assert
        verify(jdbcTemplate).update(anyString(), eq(staffSolutionSatisfaction), eq(timingSatisfaction), eq(improvementIdea));
    }

    @Test
    void testExecute_Exception() {
        // Arrange
        String staffSolutionSatisfaction = "Satisfied";
        String timingSatisfaction = "On time";
        String improvementIdea = "Improve communication";

        when(delegateExecution.getVariable("staff_Opinion")).thenReturn(staffSolutionSatisfaction);
        when(delegateExecution.getVariable("Timing")).thenReturn(timingSatisfaction);
        when(delegateExecution.getVariable("ideaSolution")).thenReturn(improvementIdea);

        // Mocking jdbcTemplate to throw an exception
        when(jdbcTemplate.update(anyString(), any(), any(), any())).thenThrow(new RuntimeException("Database error"));

        // Act & Assert
        assertDoesNotThrow(() -> surveyDataDelegate.execute(delegateExecution));

        // Verify interactions
        verify(jdbcTemplate).update(anyString(), eq(staffSolutionSatisfaction), eq(timingSatisfaction), eq(improvementIdea));
    }
}